@@ -1,5 +1,5 @@
-#  tests for terminado-0.12.1-py37h4c0cbd9_0 (this is a generated file);
-print('===== testing package: terminado-0.12.1-py37h4c0cbd9_0 =====');
+#  tests for terminado-0.13.1-py37h4c0cbd9_0 (this is a generated file);
+print('===== testing package: terminado-0.13.1-py37h4c0cbd9_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 """ run terminado tests with pytest, including platform- and python-based skips
@@ -15,12 +15,16 @@ import subprocess
 platform = sys.platform
 target_platform = os.environ["target_platform"]
 py_major = sys.version_info[:2]
+pypy = "__pypy__" in sys.builtin_module_names
 
 loader = pkgutil.get_loader("terminado.tests")
 test_path = os.path.dirname(loader.path)
 pytest = [sys.executable, "-m", "pytest"]
-cov_args = ["--cov", "terminado", "--no-cov-on-fail"]
-pytest_args = ["-vv", *cov_args, test_path]
+pytest_args = [test_path, "-vv"]
+
+if not pypy:
+    pytest_args += ["--cov", "terminado", "--no-cov-on-fail"]
+
 
 skips = []
 
@@ -52,7 +56,7 @@ print(" ".join([*pytest, *pytest_args]), flush=True)
 sys.exit(subprocess.call([*pytest, *pytest_args]))
 #  --- run_test.py (end) ---
 
-print('===== terminado-0.12.1-py37h4c0cbd9_0 OK =====');
+print('===== terminado-0.13.1-py37h4c0cbd9_0 OK =====');
 print("import: 'terminado'")
 import terminado
 
